==> pypigeon-0.2.2.tar.gz: pypigeon-0.2.2/pypigeon/pigeon_core/api/auth/auth_authenticate_user.py <==
"""Athenticates a local user."""
from http import HTTPStatus
from typing import Any
from typing import Dict
from typing import Union

import httpx

from ... import errors
from ...client import AuthenticatedClient
from ...client import Client
from ...models.auth_authenticate_user_authentication_request import (
    AuthAuthenticateUserAuthenticationRequest,
)
from ...models.auth_authenticate_user_response_200 import (
    AuthAuthenticateUserResponse200,
)
from ...models.server_error import ServerError
from ...types import Response


def _get_kwargs(
    *,
    json_body: AuthAuthenticateUserAuthenticationRequest,
) -> Dict[str, Any]:
    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": "/auth/callback/credentials",
        "json": json_json_body,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[AuthAuthenticateUserResponse200, ServerError]:
    if response.status_code == HTTPStatus.OK:
        response_200 = AuthAuthenticateUserResponse200.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = ServerError.from_dict(response.json())

        return response_400

    raise errors.UnexpectedStatus(response.status_code, response.content)


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[AuthAuthenticateUserResponse200, ServerError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: AuthAuthenticateUserAuthenticationRequest,
) -> Response[Union[AuthAuthenticateUserResponse200, ServerError]]:
    """Athenticates a local user.

    Args:
        json_body (AuthAuthenticateUserAuthenticationRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[AuthAuthenticateUserResponse200, ServerError]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: AuthAuthenticateUserAuthenticationRequest,
) -> Union[AuthAuthenticateUserResponse200]:
    """Athenticates a local user.

    Args:
        json_body (AuthAuthenticateUserAuthenticationRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns a status code greater than or equal to 300.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[AuthAuthenticateUserResponse200]
    """

    response = sync_detailed(
        client=client,
        json_body=json_body,
    )
    if isinstance(response.parsed, ServerError):
        raise errors.UnexpectedStatus(response.status_code, response.content)

    return response.parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: AuthAuthenticateUserAuthenticationRequest,
) -> Response[Union[AuthAuthenticateUserResponse200, ServerError]]:
    """Athenticates a local user.

    Args:
        json_body (AuthAuthenticateUserAuthenticationRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[AuthAuthenticateUserResponse200, ServerError]]
    """

    kwargs = _get_kwargs(
        json_body=json_body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    json_body: AuthAuthenticateUserAuthenticationRequest,
) -> Union[AuthAuthenticateUserResponse200]:
    """Athenticates a local user.

    Args:
        json_body (AuthAuthenticateUserAuthenticationRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns a status code greater than or equal to 300.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[AuthAuthenticateUserResponse200]
    """

    response = await asyncio_detailed(
        client=client,
        json_body=json_body,
    )
    if isinstance(response.parsed, ServerError):
        raise errors.UnexpectedStatus(response.status_code, response.content)

    return response.parsed

==> pypigeon-0.2.4.tar.gz: pypigeon-0.2.4/pypigeon/pigeon_core/api/auth/auth_authenticate_user.py <==
"""Athenticates a local user."""
from http import HTTPStatus
from typing import Any
from typing import Dict
from typing import Union

import httpx

from ... import errors
from ...client import AuthenticatedClient
from ...client import Client
from ...models.auth_authenticate_user_authentication_request import (
    AuthAuthenticateUserAuthenticationRequest,
)
from ...models.auth_authenticate_user_response_200 import (
    AuthAuthenticateUserResponse200,
)
from ...models.server_error import ServerError
from ...types import Response


def _get_kwargs(
    *,
    body: AuthAuthenticateUserAuthenticationRequest,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "post",
        "url": "/auth/callback/credentials",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Union[AuthAuthenticateUserResponse200, ServerError]:
    if response.status_code == HTTPStatus.OK:
        response_200 = AuthAuthenticateUserResponse200.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = ServerError.from_dict(response.json())

        return response_400

    raise errors.UnexpectedStatus(response.status_code, response.content)


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[AuthAuthenticateUserResponse200, ServerError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: AuthAuthenticateUserAuthenticationRequest,
) -> Response[Union[AuthAuthenticateUserResponse200, ServerError]]:
    """Athenticates a local user.

    Args:
        body (AuthAuthenticateUserAuthenticationRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[AuthAuthenticateUserResponse200, ServerError]]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Union[AuthenticatedClient, Client],
    body: AuthAuthenticateUserAuthenticationRequest,
) -> Union[AuthAuthenticateUserResponse200]:
    """Athenticates a local user.

    Args:
        body (AuthAuthenticateUserAuthenticationRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns a status code greater than or equal to 300.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[AuthAuthenticateUserResponse200]
    """

    response = sync_detailed(
        client=client,
        body=body,
    )
    if isinstance(response.parsed, ServerError):
        raise errors.UnexpectedStatus(response.status_code, response.content)

    return response.parsed


async def asyncio_detailed(
    *,
    client: Union[AuthenticatedClient, Client],
    body: AuthAuthenticateUserAuthenticationRequest,
) -> Response[Union[AuthAuthenticateUserResponse200, ServerError]]:
    """Athenticates a local user.

    Args:
        body (AuthAuthenticateUserAuthenticationRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[AuthAuthenticateUserResponse200, ServerError]]
    """

    kwargs = _get_kwargs(
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Union[AuthenticatedClient, Client],
    body: AuthAuthenticateUserAuthenticationRequest,
) -> Union[AuthAuthenticateUserResponse200]:
    """Athenticates a local user.

    Args:
        body (AuthAuthenticateUserAuthenticationRequest):

    Raises:
        errors.UnexpectedStatus: If the server returns a status code greater than or equal to 300.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[AuthAuthenticateUserResponse200]
    """

    response = await asyncio_detailed(
        client=client,
        body=body,
    )
    if isinstance(response.parsed, ServerError):
        raise errors.UnexpectedStatus(response.status_code, response.content)

    return response.parsed
